@@ -27,7 +27,7 @@ from adafruit_bitmap_font import bitmap_font
 from adafruit_display_text.bitmap_label import Label
 from adafruit_display_text import wrap_text_to_lines
 
-__version__ = "0.0.0-auto.0"
+__version__ = "1.14.2"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_PortalBase.git"
 
 
@@ -373,7 +373,7 @@ class PortalBase:
 
         """
         if self._alarm:
-            return self._alarm.time.PinAlarm(pin, value, edge, pull)
+            return self._alarm.pin.PinAlarm(pin, value, edge, pull)
         raise NotImplementedError(
             "Alarms not supported. Make sure you have the latest CircuitPython."
         )
@@ -385,7 +385,7 @@ class PortalBase:
         :param microcontroller.Pin pin: The trigger pin.
         """
         if self._alarm:
-            return self._alarm.time.TouchAlarm(pin)
+            return self._alarm.touch.TouchAlarm(pin)
         raise NotImplementedError(
             "Alarms not supported. Make sure you have the latest CircuitPython."
         )
